@@ -1,7 +1,13 @@
 #!/bin/sh
-#  environment setup -- HOPS_SETUP is not set or false
+#
+# $Id: chk_env.sh 332 2011-06-10 18:06:52Z gbc $
+#
+# environment setup -- HOPS_SETUP is not set or false
+# This script is really only needed for distcheck where
+# the normal setup doesn't work correctly (yet).
 #
 # ${HOPS_SETUP-'false'} || . $srcdir/chk_env.sh
+#
 
 hops=../../hops.bash
 tste=$bindir/env_check
@@ -23,19 +29,25 @@ $verb &&
     cd ./path
     for e in adump aedit alist average bispec calamp cofit \
 	     coterp fold fourfit fourmer fplot fringex \
-	     linkdata pratio search
+	     pratio search
     do
 	[ -x ../../../postproc/$e/$e ] && ln -s ../../../postproc/$e/$e .
     done
+    for e in hops_data_links.pl
+    do
+	[ -x ../../../scripts/$e ] && ln -s ../../../scripts/$e .
+    done
     export PATH=`pwd`:$PATH
     [ -z "$LD_LIBRARY_PATH" ] && LD_LIBRARY_PATH=/dev/null
     export LD_LIBRARY_PATH LD_LIBRARY_PATH=$PGPLOT_DIR:$LD_LIBRARY_PATH
     export DEF_CONTROL=/dev/null
     $verb &&
-	echo make links in `pwd` &&
+	echo made links in `pwd` &&
 	echo PATH is $PATH &&
 	echo LD_LIBRARY_PATH is $LD_LIBRARY_PATH &&
-	echo DEF_CONTROL is /dev/null
+	echo DEF_CONTROL is /dev/null &&
+	echo "bindir ($bindir) tste ($tste) hops ($hops)" &&
+	echo ''
     cd ..
 }
 
