@@ -1,5 +1,8 @@
 #!/bin/sh
-#  canonical test suite for fourfit
+#
+# $Id: chk_fringex.sh 330 2011-06-10 13:32:10Z gbc $
+#
+# canonical test suite for fringex
 #
 
 verb=false
@@ -18,8 +21,9 @@ time=oifhak
 [ -d $srcdir/testdata/$rdir ] || { echo Missing 2843 data; exit 2; }
 [ -f alist-aedit.out ] || { echo Run chk_aedit.sh first; exit 3; }
 
-$verb && echo cp -p $srcdir/testdata/$rdir/*.$time $rdir
-cp -p $srcdir/testdata/$rdir/*.$time $rdir
+$verb && echo cp $srcdir/testdata/$rdir/*.$time $rdir
+cp $srcdir/testdata/$rdir/*.$time $rdir
+chmod +w $rdir/*
 files=`ls -1 *.$time 2>&1 | wc -l`
 [ "$files" -gt 1 ] && mv *.$time $rdir &&
 $verb && echo moved $files files to $rdir
@@ -27,14 +31,15 @@ $verb && echo moved $files files to $rdir
 grep -v ' S06 ' alist-aedit.out > alist-aedit-X0X.out
 
 $verb && echo \
-fringex -i all -c -r alist-aedit-X0X.out \| average -c -o alist-aedit.coavg
-fringex -i all -c -r alist-aedit-X0X.out  |\
-average -c -o alist-aedit.coavg 2>/dev/null 1>&2
+fringex -i all -c -r alist-aedit-X0X.out \> fringex.avg
+fringex -i all -c -r alist-aedit-X0X.out  > fringex.avg
 
-lines=`cat alist-aedit.coavg | wc -l`
+lines=`cat fringex.avg | wc -l`
 $verb && echo lines is $lines
+scans=`grep endofscan fringex.avg | wc -l`
+$verb && echo scans is $scans
 
-[ "$lines" -eq 24 ]
+[ "$lines" -eq 447 -a "$scans" -eq 21 ]
 
 #
 # eof
