@@ -99,8 +99,10 @@ init_tokens ()
     tokenize (ION_WIN_,     "ion_win",    TWO_FLOAT_PARAM)
     tokenize (ION_NPTS_,    "ion_npts",   INT_PARAM)
     tokenize (INTERPOLATOR_,"interpolator",INT_PARAM)
-    tokenize (ITERATE_,     "iterate"     ,INT_CONST + ITERATE);
-    tokenize (SIMUL_,       "simul"       ,INT_CONST + SIMUL);
+    tokenize (ITERATE_,     "iterate",    INT_CONST + ITERATE)
+    tokenize (SIMUL_,       "simul",      INT_CONST + SIMUL)
     tokenize (STATION_DELAY_,"station_delay", FLOAT_PARAM)
+    tokenize (PC_DELAY_L_,  "pc_delay_l", FLOAT_PARAM)
+    tokenize (PC_DELAY_R_,  "pc_delay_r", FLOAT_PARAM)
     }
 
