@@ -60,23 +60,24 @@ struct type_pass *pass;
                     frq = pass->pass_data + fr;
                     for (ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++)
                         {
-                        
                         if (station == 0) 
                             isd = &(frq->data[ap].ref_sdata);
                         else if 
                             (station == 1) isd = &(frq->data[ap].rem_sdata);
                         if (param.pc_mode[station] == MULTITONE)
                             pcal = isd->mt_pcal[stnpol[station][pass->pol]];
-                        else
+                        else            // FIXME!! these pols shouldn't be added together
                             pcal = c_add (isd->phasecal_lcp[pass->pci[station][fr]],
                                           isd->phasecal_rcp[pass->pci[station][fr]]);
-                        if (c_mag (pcal) == 0.0) continue;
-                        ph = c_phase (pcal);
-                        ph -= (status.pc_phase[fr][station][stnpol[station][pass->pol]]
-                           - M_PI * status.pc_offset[fr][station][stnpol[station][pass->pol]] / 180.0);
-                        ph -= 2.0 * M_PI * frq->frequency * r * param.acc_period * ap;
-                        msg  ("fr %d ap %d st %d ph %g",-4, fr, ap, station, ph);
-                        delay[index] = c_add (delay[index], c_exp(ph));
+                        if (c_mag (pcal) > 0.0) 
+                            {
+                            ph = c_phase (pcal);
+                            ph -= (status.pc_phase[fr][station][stnpol[station][pass->pol]]
+                               - M_PI * status.pc_offset[fr][station][stnpol[station][pass->pol]] / 180.0);
+                            ph -= 2.0 * M_PI * frq->frequency * r * param.acc_period * ap;
+                            msg  ("fr %d ap %d st %d ph %g",-4, fr, ap, station, ph);
+                            delay[index] = c_add (delay[index], c_exp(ph));
+                            }
                         }
                     }
                 }
@@ -176,8 +177,6 @@ struct type_pass *pass;
                                     // we use the mean fraction
                                 if ((frq->data[ap].usbfrac >= 0.0) 
                                     && (frq->data[ap].lsbfrac >= 0.0)) frac /= 2.0;
-                                    // also account for possible co-added polarizations
-                                frac /= pass->npols;
                                 X = s_mult (X, frac);
                                 z = c_add (z, X);
                                 }
@@ -288,8 +287,6 @@ struct type_pass *pass;
                                     // we use the mean fraction
                                     if ((frq->data[ap].usbfrac >= 0.0) 
                                         && (frq->data[ap].lsbfrac >= 0.0)) frac /= 2.0;
-                                    // also account for possible co-added polarizations
-                                    frac /= pass->npols;
                                     X = s_mult (X, frac);
                                     delay[index] = c_add (delay[index], X);
                                     }
@@ -416,10 +413,10 @@ struct type_pass *pass;
                        /* looping done, correct delay rate for phase cal rate */
 
     status.corr_dr_max = status.dr_max_global;
-    if (param.pc_mode[0] != AP_BY_AP)
+    if (param.pc_mode[0] == NORMAL)
        status.corr_dr_max -= status.pc_rate[0];
 
-    if (param.pc_mode[1] != AP_BY_AP)
+    if (param.pc_mode[1] == NORMAL)
        status.corr_dr_max += status.pc_rate[1];
 
     msg ("phase cal rate %lg %lg", 0, status.pc_rate[0],status.pc_rate[1]);
