@@ -219,6 +219,20 @@ int parser ()
                        if (cb_ptr -> baseline[1] == WILDCARD)
                            cb_ptr -> station_delay.ref = 1e-9 * float_values[tval];
                        }
+                   else if (toknum == PC_DELAY_L_)
+                       {
+                       if (cb_ptr -> baseline[0] == WILDCARD)
+                           cb_ptr -> pc_delay_l.rem = 1e-9 * float_values[tval];
+                       if (cb_ptr -> baseline[1] == WILDCARD)
+                           cb_ptr -> pc_delay_l.ref = 1e-9 * float_values[tval];
+                       }
+                   else if (toknum == PC_DELAY_R_)
+                       {
+                       if (cb_ptr -> baseline[0] == WILDCARD)
+                           cb_ptr -> pc_delay_r.rem = 1e-9 * float_values[tval];
+                       if (cb_ptr -> baseline[1] == WILDCARD)
+                           cb_ptr -> pc_delay_r.ref = 1e-9 * float_values[tval];
+                       }
                    else if (toknum == DC_BLOCK_)
                        cb_ptr -> dc_block = tval;
                    else if (toknum == SAMPLERS_)
