@@ -108,6 +108,8 @@ struct token_struct
 #define ITERATE_         78
 #define SIMUL_           79
 #define STATION_DELAY_   80
+#define PC_DELAY_L_      81
+#define PC_DELAY_R_      82
 
 
         /* Definitions of token categories */
