@@ -21,7 +21,9 @@ struct type_pass *pass;
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L, 1:R
     complex rrpcal[2], c_mult(), c_exp(), c_add();
     double theta, c_phase(), c_mag(),
-           phaze,thyme,thyme_n,zeta;
+           phaze,thyme,thyme_n,zeta,
+           deltaf, 
+           eta[4];
     struct data_corel *cor_data;
     struct interp_sdata *rrisd[2];
     extern struct type_status status;
@@ -34,6 +36,13 @@ struct type_pass *pass;
                                            same average phase_cal phase. */
     for (fr = 0; fr < pass->nfreq; fr++)
         {
+                                        // calculate pc_delay-induced phase differences
+        deltaf = 2e6 * M_PI * (pass->pass_data[fr].frequency - param.ref_freq);
+        eta[0] = (pass->control.pc_delay_l.rem - pass->control.pc_delay_l.ref) * deltaf;
+        eta[1] = (pass->control.pc_delay_r.rem - pass->control.pc_delay_r.ref) * deltaf;
+        eta[2] = (pass->control.pc_delay_r.rem - pass->control.pc_delay_l.ref) * deltaf;
+        eta[3] = (pass->control.pc_delay_l.rem - pass->control.pc_delay_r.ref) * deltaf;
+
         for (ap = pass->ap_off; ap < pass->ap_off + pass->num_ap; ap++)
             {
             if (param.ah_phase == SINEWAVE)    /* evaluate ad hoc phase model */
@@ -93,7 +102,7 @@ struct type_pass *pass;
                 if (c_mag (rrpcal[0]) + c_mag (rrpcal[1]) == 0.0) 
                     theta = 0.0;
                                         // save resulting phasor in time-freq array
-                cor_data->pc_phasor[ip] = c_exp (theta - zeta);
+                cor_data->pc_phasor[ip] = c_exp (theta - zeta - eta[ip]);
                 }
             }
         }
